#
# spec file for package wol
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           wol
Version:        0.7.1
Release:        164.3
Summary:        Wake On Lan client
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Boot/Utilities
URL:            https://sourceforge.net/projects/wake-on-lan
Source0:        %{name}-%{version}.tar.gz
Source1:        %{name}.rules
Patch0:         wol-0.7.1-Fix-config.h-test-consumption.patch
Patch1:         wol-0.7.1-Fix-malloc-detection.patch
Patch2:         wol-0.7.1-linux-headers.patch
# fix build with gcc15
Patch3:         wol-gcc15.patch
BuildRequires:  autoconf
BuildRequires:  automake
Requires(post): %{install_info_prereq}
Requires(preun): %{install_info_prereq}

%description
The Wake On Lan client wakes up magic packet compliant machines such as
boxes with wake-on-lan ethernet-cards. Some workstations provide
SecureON which extends wake-on-lan with a password. This feature is
also provided by wol.

%package udev-rules
Summary:        Udev rules for activate %{name} via a magic packet on ethernet devices
Group:          System/Kernel
Requires:       ethtool
Requires:       udev
BuildArch:      noarch

%description udev-rules
This package contains the udev rule file for configuring ethernet devices for activate %{name} via a magic packet.

%lang_package

%prep
%autosetup -p1

%build
autoreconf -fiv
%configure --disable-rpath
%make_build

%install
%make_install
install -Dpm0644 %{SOURCE1} %{buildroot}%{_udevrulesdir}/90-%{name}.rules
%find_lang %{name}

%post
%install_info --info-dir=%{_infodir} %{_infodir}/%{name}.info%{ext_info}

%preun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/%{name}.info%{ext_info}

%files
%license COPYING
%doc ABOUT-NLS AUTHORS ChangeLog NEWS README TODO
%{_bindir}/%{name}*
%{_infodir}/%{name}.info%{?ext_info}
%{_mandir}/man?/%{name}.?%{ext_man}

%files udev-rules
%dir %{_udevrulesdir}
%{_udevrulesdir}/90-%{name}.rules

%files -f %{name}.lang lang

%changelog
* Mon Feb 17 2025 pgajdos@suse.com
- Added wol-gcc15.patch to fix build with gcc15.
* Mon Jul  8 2024 Friedrich Haubensak <hsk17@mail.de>
- Added patches for support gcc14:
  * wol-0.7.1-Fix-config.h-test-consumption.patch
  * wol-0.7.1-Fix-malloc-detection.patch
  * wol-0.7.1-linux-headers.patch
* Sat Mar 10 2018 Илья Индиго <ilya@ilya.top>
- Refresh spec-file via spec-cleaner.
- Add %%license macro.
* Mon Nov 13 2017 Илья Индиго <ilya@ilya.top>
- Refresh spec-file via spec-cleaner.
- Add package wol-udev-rules for activation wol via magic packet on ethernet devices.
- Separated localization files in a separate lang-package.
* Fri Apr  5 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
* Thu Sep 15 2011 andrea.turrini@gmail.com
- fixed typo in wol.spec
* Mon Feb 25 2008 crrodriguez@suse.de
- should be install_info_delete in postun section
* Mon Feb 25 2008 crrodriguez@suse.de
- use find_lang macro
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sat May  1 2004 nashif@suse.de
- Update to 0.7.1
* Sat Jan 10 2004 adrian@suse.de
- add %%defattr
* Tue Dec  9 2003 nashif@suse.de
- Initial Release ( Version 0.7.0 )
